pub trait ProgressCallback: Send + Sync {
// Required method
fn on_progress(&self, decoded: usize, total: usize);
}Expand description
Callback invoked by the batch engine during long-running decodes.
decoded is the number of events successfully decoded so far;
total is the total count in the current batch.
Required Methods
fn on_progress(&self, decoded: usize, total: usize)
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".